coherence.upnp.services.servers.switch_power_server (module) — Cohen3 0.8.0 documentation

# coherence.upnp.services.servers.switch_power_server (module)

## Switch Power service

class `SwitchPowerControl`(server)

  Bases: `coherence.upnp.core.service.ServiceControl`, `coherence.upnp.core.soap_service.UPnPPublisher`

class `SwitchPowerServer`(device, backend=None)

  Bases: `coherence.upnp.core.service.ServiceServer`, `twisted.web.resource.Resource`

  `logCategory` = 'switch_power_server'